@@ -51,7 +51,6 @@
 #include <QSet>
 
 using namespace Akonadi;
-using namespace AkonadiFuture;
 
 static const char KOLAB_COLLECTION[] = "KolabCollection";
 static const char KOLAB_ITEM[] = "KolabItem";
@@ -267,6 +266,7 @@ void KolabProxyResource::imapItemCreationResult(KJob* job)
 
 void KolabProxyResource::itemChanged( const Item &kolabItem, const QSet<QByteArray> &parts )
 {
+  Q_UNUSED( parts );
   kDebug() << "ITEMCHANGED" << kolabItem.id() << kolabItem.remoteId();
 
   ItemFetchJob* job = new ItemFetchJob( kolabToImap( kolabItem ), this );
@@ -303,7 +303,7 @@ void KolabProxyResource::imapItemUpdateFetchResult(KJob* job)
     // HACK FIXME how can that happen at all?
     CollectionFetchJob *fetch = new CollectionFetchJob( Collection( kolabItem.storageCollectionId() ), CollectionFetchJob::Base, this );
     fetch->setProperty( KOLAB_ITEM, QVariant::fromValue( kolabItem ) );
-    connect( fetch, SLOT(result(KJob*)), SLOT(imapUpdateCollectionFetchResult(KJob*)) );
+    connect( fetch, SIGNAL(result(KJob*)), SLOT(imapItemUpdateCollectionFetchResult(KJob*)) );
   }
 }
 
@@ -411,7 +411,7 @@ void KolabProxyResource::applyAttributesToImap( Collection &imapCollection, cons
     if ( attr->type() == "AccessRights" )
       continue;
 
-    kDebug() << "cloning" << attr->type();
+    //kDebug() << "cloning" << attr->type();
     imapCollection.addAttribute( attr->clone() );
   }
 }
@@ -431,7 +431,7 @@ void KolabProxyResource::applyAttributesFromImap( Collection &kolabCollection, c
     if ( attr->type() == "AccessRights" )
       continue;
 
-    kDebug() << "cloning" << attr->type();
+    //kDebug() << "cloning" << attr->type();
     kolabCollection.addAttribute( attr->clone() );
   }
 }
@@ -554,6 +554,7 @@ void KolabProxyResource::imapItemMoved(const Akonadi::Item& item, const Akonadi:
 
 void KolabProxyResource::imapCollectionAdded(const Collection &collection, const Collection &parent)
 {
+  Q_UNUSED( parent );
   if ( collection.resource() == identifier() ) // just to be sure...
     return;
 
@@ -585,7 +586,8 @@ void KolabProxyResource::imapCollectionChanged(const Collection &collection)
     bool isKolabFolder = false;
     if ( annotationsAttribute ) {
       const QMap<QByteArray, QByteArray> annotations = annotationsAttribute->annotations();
-      isKolabFolder = annotations.contains( "/vendor/kolab/folder-type" );
+      QByteArray folderType = annotations[ "/vendor/kolab/folder-type" ];
+      isKolabFolder = !folderType.isEmpty() && folderType != "mail";
     }
 
     if ( isKolabFolder ) {
